#~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
#DOCUMENT:      fig.com #REV:           0 
#DATE:          28/11/2008
#DEPENDENCIES:  distn
#ORIGINATOR:    Joseph Kolibal
#~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
#TO GENERATE A POSTSCRIPT FILE USING gnuplot, SO THAT THE FILE IS SCALED
#CORRECTLY. INVOKE gnuplot. THEN load 'fig.com' WHERE fig.com
#IS THE NAME OF THE COMMAND FILE. TO EXAMINE MORE OPTIONS, USE help set COMMAND
#IN gnuplot.
#THE FILE CAN BE PROCESSED FROM THE COMMAND LINE USING: gnuplot < fig.com.
#
#
#TO PLOT THE FILES CNF
#
#SETUP AXIS LABELS.
#set title "Plot Function" 0.0,0.5
#set xlabel "x" 
#set ylabel "f(x)" 0.0,0
#set noclabel
#set noborder
#set tics out
# THE COMMAND noxzeroaxis AND noyzeroaxis TURNS OF AXES IN A PLOT.
#set noxzeroaxis
set noyzeroaxis
set nolog
set nolabel
#
#SETUP THE PLOT SIZE.
# For the LaTeX and Fig terminals the default size (scale factor 1,1)
# is 5 inches wide by 3 inches high. The big Fig terminal (`bfig`) is 7
# inches wide by 5 inches high. The postscript default is landscape mode
# 10 inches wide and 7 inches high.
# Note that the size of the plot includes the space used by the labels;
# the plotting area itself is smaller.
# Size scales the size of the image, by those factors depending on the style
# chosen.
#
# FOR SLIDES:
set size 1.4, 1.0
set function style lines 
#
#
#SETUP THE TERMINAL AND ORIENTATION.
#set term postscript portrait "Times-Roman" 12
#set term postscript landscape "Times-Roman" 12
#set term postscript eps "Times-Roman" 26
#set term postscript color "Times-Roman" 16
#set term postscript portrait monochrome solid "Helvetica" 7
#set term postscript eps "Helvetica" 12
#set term postscript eps color solid  "Helvetica" 18
#set term postscript eps      color enhanced  "Helvetica" 18
set term postscript eps color solid enhanced  "Helvetica" 18
#
#SETUP THE FILENAME.
set output 'gamma.ps'
# THE COMMAND notitle AFTER THE FILENAME TURNS OFF THE LEGEND.
# THE SAMPLES COMMAND SETS THE NUMBER OF POINTS USED TO DRAW A LINE. YOU NEED
# AT LEAST 1000 FOR QUALITY GRAPHICS.
set samples 5000
#
#
# CONSTRUCT THE PLOT USING LOG SCALE
set log y
# THE PLOT SETTING LINE TYPE AND WIDTH AND MARKERS
set key left top
#set key 100 100
set key spacing 1.8
set format y "10^{%L}"
#set format x "%2.0t{/Symbol \327}10^{%L}"
#set format x "%2.0t{x}10^{%L}"
set rmargin 20
set bmargin 3
# OPTIONS FOR TIC MARKS
#set xtics (0,1,2,3,4,5,6,7,8)
#set xtics 10
#set xtics 100,200
#set mxtics 10
plot [0.01:7.12]  1 title '' lt 2, gamma(x) title 'Gamma(x)' lw 5 lt 3, 'gamma.dat' with points linetype 1  pointtype 7 pointsize '1.2' title 'n!'


# CLEAN UP:
#
set nolog
set auto
set title "" 0,0
set xlabel "" 0,0
set ylabel "" 0,0
set zlabel "" 0,0
#
#
#
#
#
#
 


